From 9bc3865d8c86392ca115ffb64a9389e92e00e861 Mon Sep 17 00:00:00 2001
From: Jonas Haag <jonas@lophus.org>
Date: Tue, 29 Dec 2015 14:14:49 +0100
Subject: [PATCH 1/3] Add setup.py

---
 acme_tiny.py          |  2 +-
 setup.py              | 28 ++++++++++++++++++++++++++++
 tests/__init__.py     |  1 +
 tests/test_install.py | 24 ++++++++++++++++++++++++
 4 files changed, 54 insertions(+), 1 deletion(-)
 create mode 100644 setup.py
 create mode 100644 tests/test_install.py

diff --git a/acme_tiny.py b/acme_tiny.py
index f54db0c..ca9ad3d 100644
--- a/acme_tiny.py
+++ b/acme_tiny.py
@@ -165,7 +165,7 @@ def _send_signed_request(url, payload):
     return """-----BEGIN CERTIFICATE-----\n{0}\n-----END CERTIFICATE-----\n""".format(
         "\n".join(textwrap.wrap(base64.b64encode(result).decode('utf8'), 64)))
 
-def main(argv):
+def main(argv=None):
     parser = argparse.ArgumentParser(
         formatter_class=argparse.RawDescriptionHelpFormatter,
         description=textwrap.dedent("""\
diff --git a/setup.py b/setup.py
new file mode 100644
index 0000000..9ed597e
--- /dev/null
+++ b/setup.py
@@ -0,0 +1,28 @@
+from setuptools import setup
+
+setup(
+    name="acme-tiny",
+    version="1.0.0",
+    url="https://github.com/diafygi/acme-tiny",
+    author="Daniel Roesler",
+    author_email="diafygi@gmail.com",
+    description="A tiny script to issue and renew TLS certs from Let's Encrypt",
+    license="MIT",
+    py_modules=['acme_tiny'],
+    entry_points={'console_scripts': [
+        'acme-tiny = acme_tiny:main',
+    ]},
+    classifiers = [
+        'Development Status :: 5 - Production/Stable',
+        'Intended Audience :: System Administrators'
+        'License :: OSI Approved :: MIT License',
+        'Operating System :: OS Independent',
+        'Programming Language :: Python',
+        'Programming Language :: Python :: 2',
+        'Programming Language :: Python :: 2.7',
+        'Programming Language :: Python :: 3',
+        'Programming Language :: Python :: 3.3',
+        'Programming Language :: Python :: 3.4',
+        'Programming Language :: Python :: 3.5',
+    ]
+)
diff --git a/tests/__init__.py b/tests/__init__.py
index ce89619..5ade34c 100644
--- a/tests/__init__.py
+++ b/tests/__init__.py
@@ -1 +1,2 @@
 from .test_module import TestModule
+from .test_install import TestInstall
diff --git a/tests/test_install.py b/tests/test_install.py
new file mode 100644
index 0000000..005f36c
--- /dev/null
+++ b/tests/test_install.py
@@ -0,0 +1,24 @@
+import unittest
+import os
+import tempfile
+import shutil
+import subprocess
+
+
+class TestInstall(unittest.TestCase):
+    def setUp(self):
+        self.tempdir = tempfile.mkdtemp()
+        subprocess.check_call(["virtualenv", self.tempdir])
+
+    def tearDown(self):
+        shutil.rmtree(self.tempdir)
+
+    def virtualenv_bin(self, cmd):
+        return os.path.join(self.tempdir, "bin", cmd)
+
+    def test_install(self):
+        subprocess.check_call([self.virtualenv_bin("python"), "setup.py", "install"])
+
+    def test_cli(self):
+        self.test_install()
+        subprocess.check_call([self.virtualenv_bin("acme-tiny"), "-h"])

From cdf1bde83d6b640a8896722557386b6d9b6a9fbb Mon Sep 17 00:00:00 2001
From: Rob Speed <speed.rob@gmail.com>
Date: Wed, 10 Feb 2016 21:53:24 -0500
Subject: [PATCH 2/3] Added setuptools_scm for automatic versioning based on
 tags.

---
 setup.py | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/setup.py b/setup.py
index 9ed597e..7ec7ef1 100644
--- a/setup.py
+++ b/setup.py
@@ -2,7 +2,7 @@
 
 setup(
     name="acme-tiny",
-    version="1.0.0",
+    use_scm_version=True,
     url="https://github.com/diafygi/acme-tiny",
     author="Daniel Roesler",
     author_email="diafygi@gmail.com",
@@ -12,6 +12,7 @@
     entry_points={'console_scripts': [
         'acme-tiny = acme_tiny:main',
     ]},
+    setup_requires=['setuptools_scm'],
     classifiers = [
         'Development Status :: 5 - Production/Stable',
         'Intended Audience :: System Administrators'

From edcaee1fa841d49a3fa488288faa8e6573269413 Mon Sep 17 00:00:00 2001
From: Matthias Bach <marix@marix.org>
Date: Mon, 22 Feb 2016 22:53:06 +0100
Subject: [PATCH 3/3] Mark wheels of acme-tiny as universal

Ensure that wheels created from the acme-tiny source are marked as universal.
---
 setup.cfg | 2 ++
 1 file changed, 2 insertions(+)
 create mode 100644 setup.cfg

diff --git a/setup.cfg b/setup.cfg
new file mode 100644
index 0000000..434559d
--- /dev/null
+++ b/setup.cfg
@@ -0,0 +1,2 @@
+[wheel]
+universal=True
